/*
 * MCP4921.c
 * 12Bit DAC via SPI
 *  Created on: 01.04.2013
 *      Author: DL9MWE
 * Anschlussbelegung des MCP4921:
 * MCP4921	MSP430
 * PIN 1  -   ./.  -  VDD   = +3,3V
 * PIN 2  -  P2.5  -  _CS - Chip select
 * PIN 3  -  P2.4  -  SCK - SPI-Clock
 * PIN 4  -  P2.3  -  SDI - SPI-Dateninput
 * PIN 5  -   ./.  -  _LDAC = GND
 * PIN 6  -   ./.  -  VREF  = +3,3V
 * PIN 7  -   ./.  -  VSS   = GND
 * PIN 8  -   ./.  -  VOUT
 *
 *	23.03.2016
 */
#include "main.h"

// SPI-Schnittstelle fr MCP4921 einstellen
//	3 Pins werden benutzt: CS, SCK, SDI
void vSPI_init(void) {
	// _CS, SDI-Clock, SDI-DataOut set to Output
	PORTDAC_DIR |= MCP4921__CS | MCP4921_SCK | MCP4921_SDI;
	PORTDAC_SEL = 0;
	PORTDAC_SEL2 = 0;				// normal IO-Function

	PORTDAC_OUT |= MCP4921__CS;		// _CS auf 1
	PORTDAC_OUT &= ~MCP4921_SCK;	// SCK auf 0
}

void vMCP4921_txWord(unsigned int data) {
	unsigned char bits;
	PORTDAC_OUT &= ~MCP4921__CS;		// _CS low
	for(bits = 16; bits != 0x00; --bits) {	// Loop until all bits are shifted
		if (data & BITF)
			PORTDAC_OUT |= MCP4921_SDI;		// SDI = 1 via pull-up
		else
			PORTDAC_OUT &= ~MCP4921_SDI;	// SDI = 0
		PORTDAC_OUT |= MCP4921_SCK;			// clock high [SCK = 1]
		data <<= 1;							// Shift bits 1 place to the left
		PORTDAC_OUT &= ~MCP4921_SCK;		// clock low [SCL = 0]
	}
	PORTDAC_OUT |= MCP4921__CS;			// _CS high

}

// Ende MCP4921.c
